==> nextcloud-18.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/sl.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Oznake",
    "Update" : "Posodobi",
    "Create" : "Ustvari",
    "Select tag…" : "Izbor oznake ...",
    "System tag %1$s added by the system" : "Dodana je sistemska oznaka %1$s",
    "Added system tag {systemtag}" : "Dodana je sistemska oznaka {systemtag}",
    "Added system tag %1$s" : "Dodana je sistemska oznaka %1$s",
    "%1$s added system tag %2$s" : "Uporabnik %1$s doda sistemsko oznako %2$s",
    "{actor} added system tag {systemtag}" : "Uporabnik {actor} doda sistemsko oznako {systemtag}",
    "Removed system tag {systemtag}" : "Odstranjena je sistemska oznaka {systemtag}",
    "Removed system tag %1$s" : "Odstranjena je sistemska oznaka %1$s",
    "%1$s created system tag %2$s" : "Uporabnik %1$s je ustvaril sistemsko oznako %2$s",
    "%1$s deleted system tag %2$s" : "Uporabnik %1$s izbriše sistemsko oznako %2$s",
    "%1$s updated system tag %3$s to %2$s" : "%1$s posodobi sistemsko oznako %3$s v%2$s",
    "You added system tag %2$s to %1$s" : "Datoteki %1$s dodate oznako %2$s.",
    "You added system tag {systemtag} to {file}" : "Datoteki {file} dodate sistemsko oznako {systemtag}",
    "%s (restricted)" : "%s (omejeno)",
    "%s (invisible)" : "%s (nevidno)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Sistemske oznake</strong> datoteke so bile spremenjene",
    "Collaborative tags" : "Sodelovalne oznake",
    "Collaborative tagging functionality which shares tags among users." : "Možnost dodajanja sodelovalnih oznak za souporabo med uporabniki.",
    "Tagged files" : "Označene datoteke",
    "Select tags to filter by" : "Izbor oznak za filtriranje",
    "No tags found" : "Ni najdenih oznak",
    "Please select tags to filter by" : "Izbor oznak za filtriranje",
    "No files found for the selected tags" : "Na izbrane oznake ni najdenih datotek",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Sodelovalne oznake so na voljo vsem uporabnikom. Omejitvene oznake so uporabnikom vidne, jih pa ni mogoče dodeliti, nevidne pa so namenjene sistemski rabi, uporabniki jih niti ne vidijo niti jih ne morejo dodeliti.",
    "Select tag …" : "Izbor oznake ...",
    "Create a new tag" : "Ustvari novo oznako",
    "Name" : "Ime",
    "Public" : "Javno",
    "Restricted" : "Omejeno",
    "Invisible" : "Nevidno",
    "Delete" : "Izbriši",
    "Reset" : "Ponastavi",
    "No files in here" : "V mapi ni datotek",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> nextcloud-18.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/systemtags/l10n/sl.js <==
OC.L10N.register(
    "systemtags",
    {
    "Tags" : "Oznake",
    "Update" : "Posodobi",
    "Create" : "Ustvari",
    "Select tag…" : "Izbor oznake ...",
    "System tag %1$s added by the system" : "Dodana je sistemska oznaka %1$s",
    "Added system tag {systemtag}" : "Dodana je sistemska oznaka {systemtag}",
    "Added system tag %1$s" : "Dodana je sistemska oznaka %1$s",
    "%1$s added system tag %2$s" : "Uporabnik %1$s doda sistemsko oznako %2$s",
    "{actor} added system tag {systemtag}" : "Uporabnik {actor} doda sistemsko oznako {systemtag}",
    "Removed system tag {systemtag}" : "Odstranjena je sistemska oznaka {systemtag}",
    "Removed system tag %1$s" : "Odstranjena je sistemska oznaka %1$s",
    "%1$s created system tag %2$s" : "Uporabnik %1$s je ustvaril sistemsko oznako %2$s",
    "%1$s deleted system tag %2$s" : "Uporabnik %1$s izbriše sistemsko oznako %2$s",
    "%1$s updated system tag %3$s to %2$s" : "%1$s posodobi sistemsko oznako %3$s v%2$s",
    "You added system tag %2$s to %1$s" : "Datoteki %1$s dodate oznako %2$s.",
    "You added system tag {systemtag} to {file}" : "Datoteki {file} dodate sistemsko oznako {systemtag}",
    "%s (restricted)" : "%s (omejeno)",
    "%s (invisible)" : "%s (nevidno)",
    "<strong>System tags</strong> for a file have been modified" : "<strong>Sistemske oznake</strong> datoteke so bile spremenjene",
    "Collaborative tags" : "Sodelovalne oznake",
    "Collaborative tagging functionality which shares tags among users." : "Možnost dodajanja sodelovalnih oznak za souporabo med uporabniki.",
    "Tagged files" : "Označene datoteke",
    "Select tags to filter by" : "Izbor oznak za filtriranje",
    "No tags found" : "Ni najdenih oznak",
    "Please select tags to filter by" : "Izbor oznak za filtriranje",
    "No files found for the selected tags" : "Na izbrane oznake ni najdenih datotek",
    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Sodelovalne oznake so na voljo vsem uporabnikom, omejitvene so uporabnikom vidne, a jih ni mogoče dodeliti, nevidne pa so namenjene sistemski rabi, uporabniki jih niti ne vidijo niti jih ne morejo dodeliti.",
    "Select tag …" : "Izbor oznake ...",
    "Create a new tag" : "Ustvari novo oznako",
    "Name" : "Ime",
    "Public" : "Javno",
    "Restricted" : "Omejeno",
    "Invisible" : "Nevidno",
    "Delete" : "Izbriši",
    "Reset" : "Ponastavi",
    "No files in here" : "V mapi ni datotek",
    "No entries found in this folder" : "V tej mapi ni najdenih predmetov.",
    "Size" : "Velikost",
    "Modified" : "Spremenjeno"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
